==> v0.6.0.tar.gz: diagrams/docs/nodes/onprem.md <==
---
id: onprem
title: OnPrem
---

Node classes list of onprem provider.

## onprem.database

- **diagrams.onprem.database.Cassandra**
- **diagrams.onprem.database.Cockroachdb**, **CockroachDB** (alias)
- **diagrams.onprem.database.Couchdb**, **CouchDB** (alias)
- **diagrams.onprem.database.Hbase**, **HBase** (alias)
- **diagrams.onprem.database.Influxdb**, **InfluxDB** (alias)
- **diagrams.onprem.database.Mariadb**, **MariaDB** (alias)
- **diagrams.onprem.database.Mongodb**, **MongoDB** (alias)
- **diagrams.onprem.database.Mssql**, **MSSQL** (alias)
- **diagrams.onprem.database.Mysql**, **MySQL** (alias)
- **diagrams.onprem.database.Neo4J**
- **diagrams.onprem.database.Oracle**
- **diagrams.onprem.database.Postgresql**, **PostgreSQL** (alias)

## onprem.ci

- **diagrams.onprem.ci.Circleci**, **CircleCI** (alias)
- **diagrams.onprem.ci.Jenkins**
- **diagrams.onprem.ci.Travisci**, **TravisCI** (alias)

## onprem.network

- **diagrams.onprem.network.Apache**
- **diagrams.onprem.network.Caddy**
- **diagrams.onprem.network.Consul**
- **diagrams.onprem.network.Envoy**
- **diagrams.onprem.network.Etcd**
- **diagrams.onprem.network.Haproxy**
- **diagrams.onprem.network.Istio**
- **diagrams.onprem.network.Kong**
- **diagrams.onprem.network.Linkerd**
- **diagrams.onprem.network.Nginx**
- **diagrams.onprem.network.Tomcat**
- **diagrams.onprem.network.Traefik**
- **diagrams.onprem.network.Zookeeper**

## onprem.inmemory

- **diagrams.onprem.inmemory.Aerospike**
- **diagrams.onprem.inmemory.Hazelcast**
- **diagrams.onprem.inmemory.Memcached**
- **diagrams.onprem.inmemory.Redis**

## onprem.search

- **diagrams.onprem.search.Elasticsearch**
- **diagrams.onprem.search.Solr**

## onprem.container

- **diagrams.onprem.container.Docker**
- **diagrams.onprem.container.Rkt**, **RKT** (alias)

## onprem.compute

- **diagrams.onprem.compute.Server**

## onprem.workflow

- **diagrams.onprem.workflow.Airflow**
- **diagrams.onprem.workflow.Kubeflow**, **KubeFlow** (alias)
- **diagrams.onprem.workflow.Nifi**, **NiFi** (alias)

## onprem.queue

- **diagrams.onprem.queue.Activemq**
- **diagrams.onprem.queue.Kafka**
- **diagrams.onprem.queue.Rabbitmq**
- **diagrams.onprem.queue.Zeromq**, **ZeroMQ** (alias)

## onprem.gitops

- **diagrams.onprem.gitops.Argocd**, **ArgoCD** (alias)

## onprem.monitoring

- **diagrams.onprem.monitoring.Datadog**
- **diagrams.onprem.monitoring.Grafana**
- **diagrams.onprem.monitoring.Kibana**
- **diagrams.onprem.monitoring.Prometheus**
- **diagrams.onprem.monitoring.Splunk**

## onprem.logging

- **diagrams.onprem.logging.Fluentd**
- **diagrams.onprem.logging.Logstash**, **LogStash** (alias)

## onprem.analytics

- **diagrams.onprem.analytics.Flink**
- **diagrams.onprem.analytics.Hadoop**
- **diagrams.onprem.analytics.Hive**
- **diagrams.onprem.analytics.Spark**
- **diagrams.onprem.analytics.Storm**

==> v0.6.4.tar.gz: diagrams/docs/nodes/onprem.md <==
---
id: onprem
title: OnPrem
---

Node classes list of onprem provider.

## onprem.database

- **diagrams.onprem.database.Cassandra**
- **diagrams.onprem.database.Cockroachdb**, **CockroachDB** (alias)
- **diagrams.onprem.database.Couchdb**, **CouchDB** (alias)
- **diagrams.onprem.database.Hbase**, **HBase** (alias)
- **diagrams.onprem.database.Influxdb**, **InfluxDB** (alias)
- **diagrams.onprem.database.Mariadb**, **MariaDB** (alias)
- **diagrams.onprem.database.Mongodb**, **MongoDB** (alias)
- **diagrams.onprem.database.Mssql**, **MSSQL** (alias)
- **diagrams.onprem.database.Mysql**, **MySQL** (alias)
- **diagrams.onprem.database.Neo4J**
- **diagrams.onprem.database.Oracle**
- **diagrams.onprem.database.Postgresql**, **PostgreSQL** (alias)

## onprem.ci

- **diagrams.onprem.ci.Circleci**, **CircleCI** (alias)
- **diagrams.onprem.ci.Jenkins**
- **diagrams.onprem.ci.Travisci**, **TravisCI** (alias)

## onprem.network

- **diagrams.onprem.network.Apache**
- **diagrams.onprem.network.Caddy**
- **diagrams.onprem.network.Consul**
- **diagrams.onprem.network.Envoy**
- **diagrams.onprem.network.Etcd**
- **diagrams.onprem.network.Haproxy**
- **diagrams.onprem.network.Istio**
- **diagrams.onprem.network.Kong**
- **diagrams.onprem.network.Linkerd**
- **diagrams.onprem.network.Nginx**
- **diagrams.onprem.network.Tomcat**
- **diagrams.onprem.network.Traefik**
- **diagrams.onprem.network.Zookeeper**

## onprem.inmemory

- **diagrams.onprem.inmemory.Aerospike**
- **diagrams.onprem.inmemory.Hazelcast**
- **diagrams.onprem.inmemory.Memcached**
- **diagrams.onprem.inmemory.Redis**

## onprem.search

- **diagrams.onprem.search.Elasticsearch**
- **diagrams.onprem.search.Solr**

## onprem.container

- **diagrams.onprem.container.Docker**
- **diagrams.onprem.container.Rkt**, **RKT** (alias)

## onprem.compute

- **diagrams.onprem.compute.Server**

## onprem.workflow

- **diagrams.onprem.workflow.Airflow**
- **diagrams.onprem.workflow.Kubeflow**, **KubeFlow** (alias)
- **diagrams.onprem.workflow.Nifi**, **NiFi** (alias)

## onprem.queue

- **diagrams.onprem.queue.Activemq**, **ActiveMQ** (alias)
- **diagrams.onprem.queue.Kafka**
- **diagrams.onprem.queue.Rabbitmq**, **RabbitMQ** (alias)
- **diagrams.onprem.queue.Zeromq**, **ZeroMQ** (alias)

## onprem.gitops

- **diagrams.onprem.gitops.Argocd**, **ArgoCD** (alias)

## onprem.monitoring

- **diagrams.onprem.monitoring.Datadog**
- **diagrams.onprem.monitoring.Grafana**
- **diagrams.onprem.monitoring.Kibana**
- **diagrams.onprem.monitoring.Prometheus**
- **diagrams.onprem.monitoring.Splunk**

## onprem.logging

- **diagrams.onprem.logging.Fluentd**
- **diagrams.onprem.logging.Logstash**, **LogStash** (alias)

## onprem.analytics

- **diagrams.onprem.analytics.Flink**
- **diagrams.onprem.analytics.Hadoop**
- **diagrams.onprem.analytics.Hive**
- **diagrams.onprem.analytics.Spark**
- **diagrams.onprem.analytics.Storm**
